@@ -1,13 +1,4 @@
 import logging
-import warnings
-from sys import version_info
-
-if version_info < (3, 7):
-    warnings.warn('Ploomber 0.20 will not support Python 3.6.\n'
-                  'Please either downgrade ploomber by running '
-                  '`pip install ploomber==0.19` or '
-                  'upgrade your Python version to 3.7+.')
-
 from ploomber.dag.dag import DAG
 from ploomber.dag.dagconfigurator import DAGConfigurator
 from ploomber.dag.inmemorydag import InMemoryDAG
@@ -18,7 +9,7 @@ from ploomber.jupyter.manager import _load_jupyter_server_extension
 from ploomber.placeholders.sourceloader import SourceLoader
 from ploomber.util.loader import lazily_load_entry_point
 
-__version__ = '0.19.9'
+__version__ = '0.20'
 
 # Set default logging handler to avoid "No handler found" warnings.
 
