@@ -2,12 +2,11 @@ from IPython import start_ipython
 from ploomber.cli.parsers import CustomParser
 from ploomber.cli.io import cli_endpoint
 from ploomber.telemetry import telemetry
-import datetime
 
 
 @cli_endpoint
+@telemetry.log_call('interact')
 def main():
-    start_time = datetime.datetime.now()
     parser = CustomParser(description='Call an entry point '
                           '(pipeline.yaml or dotted path to factory)',
                           prog='ploomber interact')
@@ -22,19 +21,14 @@ def main():
     except Exception:
         err = ('Your dag failed to render, but you can still inspect the '
                'object to debug it.\n')
-        telemetry.log_api("interact_error",
-                          dag=dag,
+        telemetry.log_api("interact-error-render",
                           metadata={
                               'type': 'dag_render_failed',
-                              'exception': err
+                              'exception': err,
+                              'dag': dag,
                           })
         print(err)
 
-    end_time = datetime.datetime.now()
-    telemetry.log_api("ploomber_interact",
-                      total_runtime=str(end_time - start_time),
-                      dag=dag)
-
     # NOTE: do not use embed here, we must use start_ipython, see here:
     # https://github.com/ipython/ipython/issues/8918
     start_ipython(argv=[], user_ns={'dag': dag})
