@@ -79,7 +79,6 @@ from IPython.display import Image
 from ploomber.table import Table, TaskReport, BuildReport
 from ploomber.products import MetaProduct
 from ploomber.util import (image_bytes2html, isiterable)
-from ploomber.util.debug import debug_if_exception
 from ploomber import resources
 from ploomber import executors
 from ploomber.executors import _format
@@ -88,7 +87,8 @@ from ploomber.exceptions import (DAGBuildError, DAGRenderError,
                                  DAGBuildEarlyStop, DAGCycle)
 from ploomber.messagecollector import (RenderExceptionsCollector,
                                        RenderWarningsCollector)
-from ploomber.util.util import callback_check, _make_requires_error_message
+from ploomber.util.util import (callback_check, _make_requires_error_message,
+                                svg2html)
 from ploomber.dag.dagconfiguration import DAGConfiguration
 from ploomber.dag.daglogger import DAGLogger
 from ploomber.dag.dagclients import DAGClients
@@ -97,7 +97,7 @@ from ploomber.dag.util import (check_duplicated_products,
                                fetch_remote_metadata_in_parallel,
                                _path_for_plot)
 from ploomber.tasks.abc import Task
-from ploomber.tasks import NotebookRunner
+from ploomber.tasks import NotebookRunner, PythonCallable
 
 if sys.version_info < (3, 8):
     # pygraphviz dropped support for python 3.7
@@ -466,7 +466,7 @@ class DAG(AbstractDAG):
     def build(self,
               force=False,
               show_progress=True,
-              debug=False,
+              debug=None,
               close_clients=True):
         """
         Runs the DAG in order so that all upstream dependencies are run for
@@ -481,11 +481,14 @@ class DAG(AbstractDAG):
         show_progress : bool, default=True
             Show progress bar
 
-        debug : bool, default=False
-            Drop a debugging session if building raises an exception. Note that
-            this modifies the executor, temporarily setting it to Serial
-            with subprocess off and catching exceptions/warnings off. Restores
-            the original executor at the end
+        debug : 'now' or 'later', default=None
+            If 'now', Drop a debugging session if building raises an exception.
+            Note that this modifies the executor and temporarily sets it
+            to Serial with subprocess off and catching exceptions/warnings off.
+            Restores the original executor at the end. If 'later' it keeps the
+            executor the same and serializes the traceback errors for later
+            debugging
+
 
         close_clients : bool, default=True
             Close all clients (dag-level, task-level and product-level) upon
@@ -495,11 +498,13 @@ class DAG(AbstractDAG):
         -----
         All dag-level clients are closed after calling this function
 
-        ``debug`` is useful to let a pipeline run and start debugging at a
-        failing  PythonCallable task but it won't work with failing
-        ``NotebookRunner`` tasks because notebooks/scripts are executed in a
-        different process. If you want to debug ``NotebookRunner`` tasks, use
-        ``NotebookRunner.debug()`` instead.
+        .. collapse:: changelog
+
+            .. versionchanged:: 0.20
+                ``debug`` changed from True/False to 'now'/'later'/None
+
+            .. versionadded:: 0.20
+                ``debug`` now supports debugging NotebookRunner tasks
 
         Returns
         -------
@@ -522,17 +527,19 @@ class DAG(AbstractDAG):
         # the debugging session in the right place
         if debug:
             executor_original = self.executor
-            self.executor = executors.Serial(build_in_subprocess=False,
-                                             catch_exceptions=False,
-                                             catch_warnings=False)
+
+            # serial debugger needed if debugnow
+            if debug == 'now':
+                self.executor = executors.Serial(build_in_subprocess=False,
+                                                 catch_exceptions=False,
+                                                 catch_warnings=False)
 
             # set debug flag to True on all tasks that have one. Currently
             # only NotebookRunner exposes this
             for name in self._iter():
                 task = self[name]
-                if isinstance(task, NotebookRunner):
-                    task._debug = True
-                    task.source._debug = True
+                if isinstance(task, (NotebookRunner, PythonCallable)):
+                    task.debug_mode = debug
 
         callable_ = partial(self._build,
                             force=force,
@@ -540,15 +547,13 @@ class DAG(AbstractDAG):
 
         with dag_logger:
             try:
-                if debug:
-                    report = debug_if_exception(callable_)
-                else:
-                    report = callable_()
+                report = callable_()
             finally:
                 if close_clients:
                     self.close_clients()
 
-        if debug:
+        # if debugging now, revert back the original executor
+        if debug == 'now':
             self.executor = executor_original
 
         return report
@@ -716,7 +721,7 @@ class DAG(AbstractDAG):
                         target,
                         force=False,
                         show_progress=True,
-                        debug=False,
+                        debug=None,
                         skip_upstream=False):
         """Partially build a dag until certain task
 
@@ -733,17 +738,29 @@ class DAG(AbstractDAG):
         show_progress : bool, default=True
             Show progress bar
 
-        debug : bool, default=False
-            Drop a debugging session if building raises an exception. Note that
-            this modifies the executor and temporarily sets it to Serial
-            with subprocess off and catching exceptions/warnings off. Restores
-            the original executor at the end.
+        debug : 'now' or 'later', default=None
+            If 'now', Drop a debugging session if building raises an exception.
+            Note that this modifies the executor and temporarily sets it
+            to Serial with subprocess off and catching exceptions/warnings off.
+            Restores the original executor at the end. If 'later' it keeps the
+            executor the same and serializes the traceback errors for later
+            debugging
 
         skip_upstream : bool, default=False
             If False, includes all upstream dependencies required to build
             target, otherwise it skips them. Note that if this is True and
             it's not possible to build a given task (e.g., missing upstream
             products), this will fail
+
+        Notes
+        -----
+        .. collapse:: changelog
+
+            .. versionchanged:: 0.20
+                ``debug`` changed from True/False to 'now'/'later'/None
+
+            .. versionadded:: 0.20
+                ``debug`` now supports debugging NotebookRunner tasks
         """
 
         # we have to use a deep copy since using a soft one will corrupt
@@ -826,8 +843,16 @@ class DAG(AbstractDAG):
                   else '.html'
             fd, path_to_plot = tempfile.mkstemp(suffix=ext)
             os.close(fd)
-            self.plot(output=path_to_plot, backend=backend)
-            plot_ = image_bytes2html(Path(path_to_plot).read_bytes())
+
+            if backend == 'pygraphviz':
+                self.plot(output=path_to_plot, backend=backend)
+                plot_ = image_bytes2html(Path(path_to_plot).read_bytes())
+            else:
+                self.plot(output=path_to_plot,
+                          backend=backend,
+                          image_only=True)
+                json_data = Path(path_to_plot).read_text()
+                plot_ = svg2html()
         else:
             plot_ = False
 
@@ -847,16 +872,25 @@ class DAG(AbstractDAG):
             out = mistune.markdown(out, escape=False, renderer=renderer)
 
             # add css
-            html = importlib_resources.read_text(resources,
-                                                 'github-markdown.html')
-            out = Template(html).render(content=out)
+            if backend == 'd3' and 'plot' in sections:
+                html = importlib_resources.read_text(
+                    resources, 'github-markdown-d3.html')
+                out = Template(html).render(content=out, json_data=json_data)
+            else:
+                html = importlib_resources.read_text(resources,
+                                                     'github-markdown.html')
+                out = Template(html).render(content=out)
 
         if path is not None:
             Path(path).write_text(out)
 
         return out
 
-    def plot(self, output='embed', include_products=False, backend=None):
+    def plot(self,
+             output='embed',
+             include_products=False,
+             backend=None,
+             image_only=False):
         """Plot the DAG
 
         Parameters
@@ -902,7 +936,7 @@ class DAG(AbstractDAG):
             dag_json = nx.readwrite.json_graph.node_link_data(G)
 
             with _path_for_plot(path_to_plot=output, fmt='html') as path:
-                plot.with_d3(dag_json, output=path)
+                plot.with_d3(dag_json, output=path, image_only=image_only)
 
                 if output == 'embed':
                     return plot.embedded_html(path=path)
