@@ -21,6 +21,13 @@ import pydantic
 from ploomber.exceptions import SpecValidationError
 
 
+class DottedPathWarning(UserWarning):
+    """Displayed in cases where raising an exception after failing to
+    initialize or load a dotted path is not necessary
+    """
+    pass
+
+
 class DottedPath:
     """
 
@@ -38,6 +45,7 @@ class DottedPath:
         If True, it allows calling the dotted path to return None, otherwise
         it raises an exception
     """
+
     def __init__(self, dotted_path, lazy_load=False, allow_return_none=True):
         self._spec = DottedPathSpecModel.from_spec(dotted_path)
         self._callable = None
@@ -338,8 +346,7 @@ def lazily_locate_dotted_path(dotted_path):
                                   f'path {dotted_path!r}, '
                                   f'no module named {first!r}')
 
-    # python 3.6 returns 'namespace', python 3.7 an up returns None
-    if spec.origin is None or spec.origin == 'namespace':
+    if spec.origin is None:
         raise ModuleNotFoundError('Error processing dotted '
                                   f'path {dotted_path!r}: '
                                   f'{first!r} appears to be a namespace '
@@ -382,6 +389,7 @@ def dotted_path_exists(dotted_path):
 class BaseModel(pydantic.BaseModel):
     """Base model for specs
     """
+
     def __init__(self, **kwargs):
         # customize ValidationError message
         try:
@@ -452,8 +460,7 @@ def create_intermediate_modules(module_parts):
     spec = importlib.util.find_spec(module_parts[0])
 
     # .origin will be None for namespace packages
-    # on Python 3.6, spec.origin is 'namespace' instead of None
-    if spec and spec.origin is not None and spec.origin != 'namespace':
+    if spec and spec.origin is not None:
         inner[0] = Path(spec.origin).parent
 
     parent = Path(*inner)
